#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_SQRTEPS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_SQRTEPS_HPP_INCLUDED

#include <boost/simd/constant/include/constants/sqrteps.hpp>

#endif
